-- 1) For every customer state and product category compute the profit and the ratio
-- between that profit and the total profit in the state

select pc.product_category, c.state_province, sum(store_sales-store_cost) as Profit,
         sum(store_sales-store_cost)/sum(sum(store_sales-store_cost)) 
		 over (partition by c.state_province) as ratio

from sales_fact s join product p on s.product_id = p.product_id
       join product_class pc on p.product_class_id = pc.product_class_id
       join customer c on s.customer_id = c.customer_id 

group by pc.product_category, c.state_province
order by pc.product_category, c.state_province, ratio desc


--2) For every customer city, year and month produce a report having: the monthly total
--sales for each city, the monthly total sales and the yearly total sales.

select c.city, t.the_year, t.the_month, sum(store_sales) as TOT_sales
from sales_fact s join product p on s.product_id = p.product_id
       join customer c on s.customer_id = c.customer_id 
	   join time_by_day t on s.time_id = t.time_id
group by rollup(t.the_year, t.the_month, c.city)
--order by t.the_year, t.the_month, c.city
order by c.city,t.the_year, t.the_month

--3) For every customer gender and customer country, the store with the highest
--percentage of sales over the total sales of all customers in that country. Result must
--be ordered by percentage descending.
with rk as 
(select c.gender, c.country, s.store_id, 
         sum(store_sales)/sum(sum(store_sales)) over (partition by c.country) as ratio,
         rank() over (partition by c.gender,c.country order by sum(store_sales) desc) as rk
from sales_fact s join product p on s.product_id = p.product_id
       join customer c on s.customer_id = c.customer_id 
group by c.gender, c.country, s.store_id) 
select gender, country, store_id, ratio
from rk where rk=1
order by ratio desc

--4) Produce a report with information about
--a. the profit of each product category, store country and year
--b. the profit of each product category
--c. the profit of each country
--d. the profit of each year
--e. the profit of each product category, store country
--f. the profit of each product category, year
--g. the profit of each store country and year
--h. the total profit

select pc.product_category, st.store_country, t.the_year, sum(store_sales-store_cost) as profit
from sales_fact s join product p on s.product_id = p.product_id
       join customer c on s.customer_id = c.customer_id 
	   join time_by_day t on s.time_id = t.time_id
	    join product_class pc on p.product_class_id = pc.product_class_id
	   join store st on st.store_id=s.store_id
group by cube(pc.product_category, st.store_country, t.the_year)
order by pc.product_category, st.store_country, t.the_year

--5) For each product category and store country return the ranking of the customers
--with respect to the store sales. 

select  pc.product_category, st.store_country,  s.customer_id, sum(store_sales) as totSales,
         rank() over (partition by pc.product_category, st.store_country order by sum(store_sales) desc) as rk
from sales_fact s join product p on s.product_id = p.product_id
       join product_class pc on p.product_class_id = pc.product_class_id
	   join store st on st.store_id=s.store_id
group by pc.product_category, st.store_country, s.customer_id
